class Hash:
    def bits(self) -> list[list[bool]]: ...
    def hex(self) -> str: ...

def average_hash(path: str, width: int = 8, height: int = 8) -> Hash: ...
def difference_hash(path: str, width: int = 8, height: int = 8) -> Hash: ...
def perceptual_hash(path: str, width: int = 8, height: int = 8) -> Hash: ...
